@@ -12,8 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Modular OpenAI-compatible API server for Calute agents."""
 
+"""Modular OpenAI-compatible API server for Calute agents with Cortex support."""
+
+from .cortex_completion_service import CortexCompletionService
 from .server import CaluteAPIServer
 
-__all__ = ["CaluteAPIServer"]
+__all__ = ["CaluteAPIServer", "CortexCompletionService"]
