@@ -11,11 +11,29 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
+
+"""Function execution and agent orchestration system.
+
+This module provides the core execution infrastructure for Calute,
+including:
+- Function registry and management
+- Agent orchestration and switching
+- Function execution with various strategies (sequential, parallel, pipeline)
+- Retry policies and error handling
+- Execution metrics and monitoring
+- Enhanced versions with additional features
+
+The module supports both synchronous and asynchronous function execution,
+timeout management, and sophisticated error recovery mechanisms.
+"""
+
 from __future__ import annotations
 
 import asyncio
 import functools
 import inspect
+import json
 import logging
 import time
 import typing as tp
@@ -44,43 +62,92 @@ add_depth = (  # noqa
 
 
 class FunctionRegistry:
-    """Registry for managing functions across agents"""
+    """Registry for managing functions across agents.
+
+    Maintains a central registry of all functions available in the system,
+    tracking which agent owns each function and associated metadata.
+
+    Attributes:
+        _functions: Dictionary mapping function names to callable functions.
+        _function_agents: Dictionary mapping function names to agent IDs.
+        _function_metadata: Dictionary mapping function names to metadata.
+    """
 
     def __init__(self):
+        """Initialize an empty function registry."""
         self._functions: dict[str, tp.Callable] = {}
-        self._function_agents: dict[str, str] = {}  # function_name -> agent_id
+        self._function_agents: dict[str, str] = {}
         self._function_metadata: dict[str, dict] = {}
 
     def register(self, func: tp.Callable, agent_id: str, metadata: dict | None = None):
-        """Register a function with the registry"""
+        """Register a function with the registry.
+
+        Args:
+            func: The callable function to register.
+            agent_id: ID of the agent that owns this function.
+            metadata: Optional metadata about the function.
+        """
         func_name = func.__name__
         self._functions[func_name] = func
         self._function_agents[func_name] = agent_id
         self._function_metadata[func_name] = metadata or {}
 
     def get_function(self, name: str) -> tuple[tp.Callable | None, str | None]:
-        """Get function and its associated agent"""
+        """Get function and its associated agent.
+
+        Args:
+            name: Name of the function to retrieve.
+
+        Returns:
+            Tuple of (function, agent_id) or (None, None) if not found.
+        """
         func = self._functions.get(name)
         agent_id = self._function_agents.get(name)
         return func, agent_id
 
     def get_functions_by_agent(self, agent_id: str) -> list[tp.Callable]:
-        """Get all functions for a specific agent"""
+        """Get all functions for a specific agent.
+
+        Args:
+            agent_id: ID of the agent.
+
+        Returns:
+            List of functions registered to the agent.
+        """
         return [func for func_name, func in self._functions.items() if self._function_agents[func_name] == agent_id]
 
 
 class AgentOrchestrator:
-    """Orchestrates multiple agents and handles switching logic"""
+    """Orchestrates multiple agents and handles switching logic.
+
+    Manages a collection of agents, their functions, and the logic for
+    switching between agents based on various triggers.
+
+    Attributes:
+        agents: Dictionary of registered agents by ID.
+        function_registry: Registry of all available functions.
+        switch_triggers: Dictionary of trigger handlers for agent switching.
+        current_agent_id: ID of the currently active agent.
+        execution_history: History of agent switches and executions.
+    """
 
     def __init__(self):
+        """Initialize the agent orchestrator."""
         self.agents: dict[str, Agent] = {}
         self.function_registry = FunctionRegistry()
         self.switch_triggers: dict[AgentSwitchTrigger, tp.Callable] = {}
         self.current_agent_id: str | None = None
         self.execution_history: list[dict] = []
 
-    def register_agent(self, agent: Agent):
-        """Register an agent with the orchestrator"""
+    def register_agent(self, agent: Agent) -> None:
+        """Register an agent with the orchestrator.
+
+        Args:
+            agent: The agent instance to register.
+
+        Returns:
+            None
+        """
         agent_id = agent.id or f"agent_{len(self.agents)}"
         agent.id = agent_id
         self.agents[agent_id] = agent
@@ -91,20 +158,46 @@ class AgentOrchestrator:
         if self.current_agent_id is None:
             self.current_agent_id = agent_id
 
-    def register_switch_trigger(self, trigger: AgentSwitchTrigger, handler: tp.Callable):
-        """Register a custom switch trigger handler"""
+    def register_switch_trigger(self, trigger: AgentSwitchTrigger, handler: tp.Callable) -> None:
+        """Register a custom switch trigger handler.
+
+        Args:
+            trigger: The trigger type to register.
+            handler: The callable handler for this trigger.
+
+        Returns:
+            None
+        """
         self.switch_triggers[trigger] = handler
 
     def should_switch_agent(self, context: dict) -> str | None:
-        """Determine if agent switching is needed"""
+        """Determine if agent switching is needed.
+
+        Args:
+            context: The current execution context.
+
+        Returns:
+            The ID of the target agent if switching is needed, None otherwise.
+        """
         for _, handler in self.switch_triggers.items():
             target_agent = handler(context, self.agents, self.current_agent_id)
             if target_agent and target_agent != self.current_agent_id:
                 return target_agent
         return None
 
-    def switch_agent(self, target_agent_id: str, reason: str | None = None):
-        """Switch to a different agent"""
+    def switch_agent(self, target_agent_id: str, reason: str | None = None) -> None:
+        """Switch to a different agent.
+
+        Args:
+            target_agent_id: ID of the agent to switch to.
+            reason: Optional reason for the switch.
+
+        Returns:
+            None
+
+        Raises:
+            ValueError: If the target agent is not found.
+        """
         if target_agent_id not in self.agents:
             raise ValueError(f"Agent {target_agent_id} not found")
 
@@ -122,13 +215,24 @@ class AgentOrchestrator:
         )
 
     def get_current_agent(self) -> Agent:
-        """Get the currently active agent"""
+        """Get the currently active agent.
+
+        Returns:
+            The currently active Agent instance.
+
+        Raises:
+            ValueError: If no agent is currently active.
+        """
         if not self.current_agent_id:
             raise ValueError("No active agent")
         return self.agents[self.current_agent_id]
 
     def _get_timestamp(self) -> str:
-        """Get current timestamp"""
+        """Get current timestamp in ISO format.
+
+        Returns:
+            Current timestamp as an ISO formatted string.
+        """
         import datetime
 
         return datetime.datetime.now().isoformat()
@@ -244,7 +348,9 @@ class FunctionExecutor:
         agent: Agent | None = None,
     ) -> list[RequestFunctionCall]:
         """Execute calls in parallel"""
-        tasks = [self._execute_single_call(call, context.copy(), agent) for call in calls]
+
+        context_dict = context if isinstance(context, dict) else {}
+        tasks = [self._execute_single_call(call, context_dict.copy(), agent) for call in calls]
         results = await asyncio.gather(*tasks, return_exceptions=True)
         final_results: list[RequestFunctionCall] = []
         for call, result in zip(calls, results, strict=False):
@@ -268,7 +374,9 @@ class FunctionExecutor:
     ) -> list[RequestFunctionCall]:
         """Execute calls in a pipeline where output of one feeds into next"""
         results = []
-        current_context = context.copy()
+
+        context_dict = context if isinstance(context, dict) else {}
+        current_context = context_dict.copy()
 
         for call in calls:
             result = await self._execute_single_call(call, current_context, agent)
@@ -323,7 +431,10 @@ class FunctionExecutor:
 
                 if not func:
                     raise ValueError(f"Function {call.name} not found")
-                args = call.arguments.copy()
+                if isinstance(call.arguments, dict):
+                    args = call.arguments.copy()
+                elif isinstance(call.arguments, str):
+                    args = {} if call.arguments == "" else json.loads(call.arguments)
                 if __CTX_VARS_NAME__ in func.__code__.co_varnames:
                     args[__CTX_VARS_NAME__] = context
                     if self.execution_history.executions:
@@ -393,10 +504,6 @@ class FunctionExecutor:
         return all(dep in completed_ids for dep in call.dependencies)
 
 
-# ===========================
-# ENHANCED CLASSES BELOW
-# ===========================
-
 try:
     from .errors import (
         AgentError,
@@ -405,7 +512,7 @@ try:
         ValidationError,
     )
 except ImportError:
-    # Define stub errors if errors module is not available
+
     class AgentError(Exception):  # type: ignore[no-redef]
         def __init__(self, agent_id: str, message: str):
             super().__init__(f"Agent {agent_id}: {message}")
@@ -473,7 +580,6 @@ class ExecutionMetrics:
             self.successful_calls += 1
         elif status == ExecutionStatus.FAILURE:
             self.failed_calls += 1
-        # Note: We count timeouts as failures since there's no TIMEOUT status
 
         self.max_duration = max(self.max_duration, duration)
         self.min_duration = min(self.min_duration, duration)
@@ -500,7 +606,6 @@ class EnhancedFunctionRegistry:
         """Register a function with validation."""
         func_name = func.__name__
 
-        # Validate function signature
         sig = inspect.signature(func)
         if not sig.parameters:
             logger.warning(f"Function {func_name} has no parameters")
@@ -521,7 +626,6 @@ class EnhancedFunctionRegistry:
         func = self._functions[func_name]
         sig = inspect.signature(func)
 
-        # Check required parameters
         for param_name, param in sig.parameters.items():
             if param_name == __CTX_VARS_NAME__:
                 continue
@@ -529,7 +633,6 @@ class EnhancedFunctionRegistry:
             if param.default == inspect.Parameter.empty and param_name not in arguments:
                 raise ValidationError(param_name, f"Required parameter missing for {func_name}")
 
-        # Run custom validator if provided
         validator = self._function_validators.get(func_name)
         if validator:
             validator(arguments)
@@ -566,7 +669,6 @@ class EnhancedAgentOrchestrator:
 
             self.agents[agent_id] = agent
 
-            # Register functions with validation
             for func in agent.functions:
                 try:
                     self.function_registry.register(func, agent_id)
@@ -648,7 +750,6 @@ class EnhancedFunctionExecutor:
             if asyncio.iscoroutinefunction(func):
                 return await asyncio.wait_for(func(**arguments), timeout=timeout)
             else:
-                # Run sync function in thread pool
                 loop = asyncio.get_event_loop()
                 future = loop.run_in_executor(self.thread_pool, functools.partial(func, **arguments))
                 return await asyncio.wait_for(future, timeout=timeout)
@@ -674,7 +775,6 @@ class EnhancedFunctionExecutor:
                 return await self.execute_with_timeout(func, arguments, timeout)
 
             except CaluteTimeoutError:
-                # Don't retry timeouts
                 raise
 
             except FunctionExecutionError as e:
@@ -701,29 +801,24 @@ class EnhancedFunctionExecutor:
             func_name = call.name
 
             try:
-                # Get function and validate
                 func = self.orchestrator.function_registry._functions.get(func_name)
 
                 if not func:
                     raise FunctionExecutionError(func_name, "Function not found")
 
-                # Validate arguments
                 self.orchestrator.function_registry.validate_arguments(func_name, call.arguments)
 
-                # Add context variables if needed
                 if __CTX_VARS_NAME__ in inspect.signature(func).parameters:
                     call.arguments[__CTX_VARS_NAME__] = context_variables or {}
 
-                # Get timeout from agent or use default
                 timeout = (
                     agent.function_timeout if agent and hasattr(agent, "function_timeout") else self.default_timeout
                 )
 
-                # Execute with retry
                 result = await self.execute_with_retry(func, call.arguments, timeout)
 
                 call.result = result
-                # Add status if not present
+
                 if not hasattr(call, "status"):
                     call.status = ExecutionStatus.SUCCESS
                 else:
@@ -738,7 +833,7 @@ class EnhancedFunctionExecutor:
             except CaluteTimeoutError as e:
                 call.result = f"Function timed out: {e}"
                 if hasattr(call, "status"):
-                    call.status = ExecutionStatus.FAILURE  # Use FAILURE for timeout
+                    call.status = ExecutionStatus.FAILURE
                 if hasattr(call, "error"):
                     call.error = str(e)
                 if hasattr(call, "execution_time"):
@@ -766,7 +861,6 @@ class EnhancedFunctionExecutor:
                 logger.error(f"Unexpected error in {func_name}: {e}", exc_info=True)
 
             finally:
-                # Record metrics
                 if self.orchestrator.enable_metrics:
                     metrics = self.orchestrator.function_registry.get_metrics(func_name)
                     if metrics:
@@ -791,12 +885,13 @@ class EnhancedFunctionExecutor:
             for call in calls:
                 result = await self.execute_single_call(call, context_variables, agent)
                 results.append(result)
-                # Update context with result for next call
+
                 if result.status == ExecutionStatus.SUCCESS:
                     context_variables[f"{call.name}_result"] = result.result
 
         elif strategy == FunctionCallStrategy.PARALLEL:
-            tasks = [self.execute_single_call(call, context_variables.copy(), agent) for call in calls]
+            context_dict = context_variables if isinstance(context_variables, dict) else {}
+            tasks = [self.execute_single_call(call, context_dict.copy(), agent) for call in calls]
             results = await asyncio.gather(*tasks, return_exceptions=False)
 
         else:
@@ -810,8 +905,7 @@ class EnhancedFunctionExecutor:
         try:
             yield self
         finally:
-            # Cleanup resources
-            await asyncio.sleep(0)  # Allow pending tasks to complete
+            await asyncio.sleep(0)
 
     def __del__(self):
         """Cleanup thread pool on deletion."""
